@@ -49,8 +49,10 @@ class WorkspaceRequestHandler(SimpleHTTPRequestHandler):
             "step_class_name": step_info.step_class_name,
             "version": step_info.version,
             "dependencies": list(step_info.dependencies),
-            "start_time": step_info.start_time.isoformat() if step_info.start_time else None,
-            "end_time": step_info.end_time.isoformat() if step_info.end_time else None,
+            "start_time": step_info.start_time_local.isoformat()
+            if step_info.start_time_local
+            else None,
+            "end_time": step_info.end_time_local.isoformat() if step_info.end_time_local else None,
             "error": error,
             "result_location": result_location,
             "state": step_info.state.value,
@@ -120,7 +122,7 @@ class WorkspaceServer(ThreadingHTTPServer):
 
     @classmethod
     def on_free_port(cls, workspace: Workspace, start_port: int = 8080) -> "WorkspaceServer":
-        for port in range(start_port, 2 ** 16):
+        for port in range(start_port, 2**16):
             try:
                 return cls(("", port), workspace)
             except OSError as e:
